Add GFX908 specific changes to HIP (#1229)

* Add GFX908 specific for HIP

* Fix missing __halfTest in hipTestNativeHalf
This commit is contained in:
Aaron Enye Shi
2019-07-24 03:51:17 -04:00
committed by Maneesh Gupta
parent 75abc65e12
commit b754de37c1
8 changed files with 30 additions and 7 deletions
+1 -1
View File
@@ -29,7 +29,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
#include "test_common.h"
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__ || __HIP_ARCH_GFX908__
__global__ void kernel_abs_int64(long long *input, long long *output) {
int tx = threadIdx.x;